# DEVELOPERS

## Principal Investigators
- Herald Binsar M. H. Sinaga, S.T.
- Ir. Zuher Syihab, Ph.D
- Ir. Sudono, M.T.

## Primary Developers
- Dr. Eng. Aditya Dewanto Hartono, 
- Dr. Ir. Fajril Ambia, M.T.
- Dr. Ir. Iskandar Fahmi
- Muhammad Adhim Mulia, M.T.

<br>

> We welcome you to our economic toolkit.
> This package contains tailored functionalities for assessing economic feasibility of oil and gas projects
> following the state-of-the-art Production Sharing Contract (PSC) schemes in Indonesia.

> **PySCnomics** is the product of join research between Indonesia's Special Task Force for Upstream Oil and Gas Business Activities (SKK Migas) and the Department of Petroleum
> Engineering, Institut Teknologi Bandung (ITB). 

<br>

All rights belong to &copy; SKK Migas.<br>
This is **PySCnomics** version 1.0.0 <br>
2024
 